From 2cb1563f63386b35a69e460051aa9b4a2851d104 Mon Sep 17 00:00:00 2001
From: ftimme <ft@falkotimme.com>
Date: Wed, 30 May 2012 07:30:44 -0400
Subject: [PATCH] - Added (clickable) placeholders to client messaging function. - Added check so that the client password isn't inserted into the message (for security reasons).

---
 interface/web/mail/mail_whitelist_edit.php |   83 ++++++++++++++++++++++-------------------
 1 files changed, 45 insertions(+), 38 deletions(-)

diff --git a/interface/web/mail/mail_whitelist_edit.php b/interface/web/mail/mail_whitelist_edit.php
index ece39d5..a377729 100644
--- a/interface/web/mail/mail_whitelist_edit.php
+++ b/interface/web/mail/mail_whitelist_edit.php
@@ -41,58 +41,65 @@
 require_once('../../lib/config.inc.php');
 require_once('../../lib/app.inc.php');
 
-// Checking module permissions
-if(!stristr($_SESSION["s"]["user"]["modules"],$_SESSION["s"]["module"]["name"])) {
-	header("Location: ../index.php");
-	exit;
-}
+//* Check permissions for module
+$app->auth->check_module_permissions('mail');
 
 // Loading classes
 $app->uses('tpl,tform,tform_actions');
 $app->load('tform_actions');
 
 class page_action extends tform_actions {
-	
-	function onShowEnd() {
+
+	function onShowNew() {
 		global $app, $conf;
 		
-		// Getting recipient from data record
-		$recipient = $this->dataRecord["recipient"];
-		$email_parts = explode("@",$recipient);
-		$app->tpl->setVar("recipient_local_part",$email_parts[0]);
-		
-		// Getting Domains of the user
-		$sql = "SELECT domain FROM mail_domain WHERE type = 'local' AND ".$app->tform->getAuthSQL('r');
-		$domains = $app->db->queryAllRecords($sql);
-		$domain_select = '';
-		if($_SESSION["s"]["user"]["typ"] == 'admin') $domain_select .= '<option value=""></option>';
-		foreach( $domains as $domain) {
-			$selected = ($domain["domain"] == $email_parts[1])?'SELECTED':'';
-			$domain_select .= "<option value='$domain[domain]' $selected>$domain[domain]</option>\r\n";
+		// we will check only users, not admins
+		if($_SESSION["s"]["user"]["typ"] == 'user') {
+			if(!$app->tform->checkClientLimit('limit_mailfilter')) {
+				$app->error($app->tform->wordbook["limit_mailfilter_txt"]);
+			}
+			if(!$app->tform->checkResellerLimit('limit_mailfilter')) {
+				$app->error('Reseller: '.$app->tform->wordbook["limit_mailfilter_txt"]);
+			}
 		}
-		$app->tpl->setVar("recipient_domain",$domain_select);
 		
-		parent::onShowEnd();
+		parent::onShowNew();
 	}
 	
+	function onBeforeUpdate() {
+		global $app, $conf;
+
+		//* Check if the server has been changed
+		// We do this only for the admin or reseller users, as normal clients can not change the server ID anyway
+		if($_SESSION["s"]["user"]["typ"] == 'admin' || $app->auth->has_clients($_SESSION['s']['user']['userid'])) {
+			$rec = $app->db->queryOneRecord("SELECT server_id from mail_access WHERE access_id = ".$this->id);
+			if($rec['server_id'] != $this->dataRecord["server_id"]) {
+				//* Add a error message and switch back to old server
+				$app->tform->errorMessage .= $app->lng('The Server can not be changed.');
+				$this->dataRecord["server_id"] = $rec['server_id'];
+			}
+			unset($rec);
+		}
+	}
+
 	function onSubmit() {
 		global $app, $conf;
-		
-		// Check if Domain belongs to user
-		$domain = $app->db->queryOneRecord("SELECT server_id, domain FROM mail_domain WHERE domain = '".$app->db->quote($_POST["recipient_domain"])."' AND ".$app->tform->getAuthSQL('r'));
-		if($domain["domain"] != $_POST["recipient_domain"]) $app->tform->errorMessage .= $app->tform->wordbook["no_domain_perm"];
-		
-		// compose the email field
-		if($_POST["recipient_local_part"] != '') {
-			$this->dataRecord["recipient"] = $_POST["recipient_local_part"]."@".$_POST["recipient_domain"];
-		} else {
-			$this->dataRecord["recipient"] = $_POST["recipient_domain"];
-		}
-		// Set the server id of the mailbox = server ID of mail domain.
-		// $this->dataRecord["server_id"] = $domain["server_id"];
-		
-		unset($this->dataRecord["recipient_local_part"]);
-		unset($this->dataRecord["recipient_domain"]);
+				
+		// Check the client limits, if user is not the admin
+		if($_SESSION["s"]["user"]["typ"] != 'admin') { // if user is not admin
+			// Get the limits of the client
+			$client_group_id = $_SESSION["s"]["user"]["default_group"];
+			$client = $app->db->queryOneRecord("SELECT limit_mailfilter FROM sys_group, client WHERE sys_group.client_id = client.client_id and sys_group.groupid = $client_group_id");
+
+			// Check if the user may add another mailbox.
+			if($this->id == 0 && $client["limit_mailfilter"] >= 0) {
+				$tmp = $app->db->queryOneRecord("SELECT count(access_id) as number FROM mail_access WHERE sys_groupid = $client_group_id");
+				if($tmp["number"] >= $client["limit_mailfilter"]) {
+					$app->tform->errorMessage .= $app->tform->wordbook["limit_mailfilter_txt"]."<br>";
+				}
+				unset($tmp);
+			}
+		} // end if user is not admin
 		
 		parent::onSubmit();
 	}

--
Gitblit v1.9.1